@@ -19,7 +19,7 @@ class Avto(models.Model):
     title_sale_doc = models.CharField(max_length=255, blank=True, verbose_name='Title/Sale Doc')
     start_code = models.CharField(max_length=255, blank=True, verbose_name='Start Code')
     key_fob = models.CharField(max_length=255, blank=True, verbose_name='Key/Fob')
-    odometer = models.FloatField(default=-1, verbose_name='Odometer', default='')
+    odometer = models.FloatField(default=-1, verbose_name='Odometer')
     odometer_desc = models.CharField(max_length=255, blank=True, verbose_name='Odometer extra', default='')
     airbags = models.CharField(max_length=255, blank=True, verbose_name='Airbags')
     vehicle = models.CharField(max_length=255, blank=True, verbose_name='Vehicle')
